import { Pressable, SafeAreaView, Platform, KeyboardAvoidingView, TextInput, StyleSheet, Text, View, Dimensions, Image, PixelRatio, FlatList, ImageBackground } from "react-native";
import { Images, Themes } from "../../../assets/Themes";
import Constants from "expo-constants";
import React, { useState } from "react";

const windowWidth = Dimensions.get("window").width;
const windowHeight = Dimensions.get("window").height;
import ChatSupport from "./ChatSupport";

class Chat extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      text: "",
      chats: [],
    };
    this.nav = this.props.navigation;
    this.params = this.props.route.params;
  }

  setChats(newChats) {
    this.setState({ chats: newChats });
  }

  setText(newText) {
    this.setState({ text: newText });
  }

  addChat = () => {
    let newChats = [...this.state.chats];
    newChats.push(this.state.text);
    this.setChats(newChats);
    this.setText("");
  };



  renderList = ({ item }) => {
    return (
      <ChatSupport
        text={item}
      />
    );
  };

  render() {
    return (
      <ImageBackground style={styles.container} source={Images.chat}>
        <View style={styles.headerbar}>
          <Pressable onPress={() => this.nav.navigate('Home', {username:this.params.username})}>
            <Image
              style={styles.homeButtonImg}
              source={Images.homeButton}
            />
          </Pressable>
        </View>
        <View style={styles.surveyScreen}>
          <View style={styles.surveyContent}>
            <SafeAreaView styles={styles.flatList}>
              <FlatList
                data={this.state.chats}
                renderItem={this.renderList}
                keyExtractor={(item, index) => item + index}
                ListFooterComponent={
                  <View>
                    <View style={{
                      flexDirection: "row",
                      justifyContent: "center",
                      alignItems: "flex-end",
                      height: windowHeight * 0.60
                    }}>
                      <KeyboardAvoidingView
                        behavior={Platform.OS === "ios" ? "padding" : "height"}>
                        <View style={styles.textinputrow}>
                          <TextInput
                            style={styles.textInput}
                            placeholder="Type chat..."
                            onChangeText={(newText) => this.setText(newText)}
                            defaultValue={this.state.text}
                          />
                        </View>
                      </KeyboardAvoidingView>
                      <View
                      >
                        <Pressable
                          style={styles.button}>
                          <Image

                            source={Images.send}
                          />
                        </Pressable>
                      </View>
                    </View>

                  </View>
                }
              />
            </SafeAreaView>
          </View>
          <View style={styles.navBox}>
            <View style={Themes.shadows}>
              <Pressable style={styles.backButton} >
                <Text style={styles.buttonText} onPress={() => this.nav.navigate('FriendGarden', {username:this.params.username})}>
                  BACK
                </Text>
              </Pressable>
            </View>
          </View>
        </View>

      </ImageBackground>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: Themes.colors.background,
    paddingTop: Constants.statusBarHeight,
    alignItems: "center",
    justifyContent: "center",
  },
  buttonText: {
    color: Themes.colors.darkBrown,
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.022,
  },
  backButton: {
    width: windowWidth * 0.30,
    height: windowHeight * 0.07,
    alignItems: 'center',
    justifyContent: "center",
    backgroundColor: Themes.colors.pink,
    borderRadius: 10,
    marginTop: 30
  },
  navBox: {
    width: windowWidth,
    height: windowHeight * 0.15,
    flexDirection: 'row',
    justifyContent: "center",
    alignItems: "center",
    padding: 50,
    paddingBottom: 20
  },
  headerbar: {
    width: windowWidth,
    height: windowHeight * 0.025,
    flexDirection: 'row',
    alignItems: 'flex-start',
    backgroundColor: Themes.colors.background,
  },
  surveyScreen: {
    flex: 1,
    flexDirection: "column",
    alignContent: "flex-start",
  },
  surveyContent: {
    width: windowWidth,
    height: windowHeight * 0.6,
    flexDirection: "column",
    alignItems: "center",
  },
  questionBox: {
    width: windowWidth,
    height: windowHeight * 0.1,
    flexDirection: "column",
    alignItems: "center",
  },
  questionText: {
    color: Themes.colors.subtext,
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.024,
    alignContent: "center",
    justifyContent: "center",
  },
  flatList: {
    alignContent: "flex-end",
    margin: 10,
    flexDirection: "column",
  },
  textInput: {
    width: windowWidth * 0.65,
    height: windowHeight * 0.05,
    flexDirection: "row",
    margin: 10,
    alignItems: "center",
    justifyContent: "center",
    backgroundColor: Themes.colors.white,
    borderRadius: 10,
    paddingHorizontal: 75,
    color: Themes.colors.black,
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.024,
  },
  textinputrow: {
    flexDirection: "row",
    alignContent: "center",
    marginBottom: 10,
  },
  title: {
    fontSize: 30,
    color: Themes.colors.black,
  },
  button: {
    width: windowWidth * 0.16,
    height: windowWidth * 0.16,
    flexDirection: "row",
    alignItems: "center",
    justifyContent: "center",
    borderRadius: 99999,
    margin: 5,
  },
  buttonImage: {
    width: windowWidth * 0.1,
    height: windowWidth * 0.1,
    alignItems: "center",
    justifyContent: "center",
    borderRadius: 99999,
  },
  emotionBox: {
    width: windowWidth * 0.65,
    height: windowHeight * 0.05,
    flexDirection: "row",
    margin: 10,
    alignItems: "center",
    justifyContent: "center",
    backgroundColor: Themes.colors.white,
    borderRadius: 10,
  },
});

export default Chat;
