import { Pressable, SafeAreaView, ImageBackground, StyleSheet, Text, View, Dimensions, Image, PixelRatio, FlatList } from "react-native";
import { Images, Themes } from "../../../assets/Themes";
import Constants from 'expo-constants';
import React, { useState } from 'react';
const windowWidth = Dimensions.get('window').width;
const windowHeight = Dimensions.get('window').height;



class FriendGarden extends React.Component {
  constructor(props) {
    super(props);

    this.state = {

    };
    this.nav = this.props.navigation;
    this.params = this.props.route.params;
  }

  render() {
    return (
      <ImageBackground
        style={styles.container}
        source={Images.piggardenscreen}>
        <View style={styles.top_container}>
          <Header nav={this.props.navigation} username={this.params.username} />
        </View>
        <Nav nav={this.props.navigation} username={this.params.username} />
      </ImageBackground>





    );
  }
}

const Header = (props) => {
  return (
    <View>
      <View style={styles.headerbar}>
        <Pressable onPress={() => props.nav.navigate('Home', { username: props.username })}>
          <Image
            style={styles.homeButtonImg}
            source={Images.homeButton}
          />
        </Pressable>

        <Pressable onPress={() => props.nav.navigate('Chat', { username: props.username })}>
          <Image
            style={styles.chatButtonImg}
            source={Images.chatButton}
          />
        </Pressable>
      </View>

      <View style={styles.greetingBar}>
        <Text style={styles.titleText}>
          Your Friend's Garden
        </Text>
      </View>
    </View>
  );
}

const Nav = (props) => {
  return (
    <View style={styles.navBox}>
      <View style={Themes.shadows}>
        <Pressable style={styles.backButton} onPress={() => props.nav.navigate('MainFriendScreen', { username: props.username })}>
          <Text style={styles.buttonText}>
            BACK TO FRIENDS
          </Text>
        </Pressable>
      </View>
    </View>
  );
}

export default FriendGarden;

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: Themes.colors.background,
    flex: 1,
    paddingTop: Constants.statusBarHeight,
    alignItems: 'center',
    justifyContent: 'center',
  },
  friendsScreen: {
    flex: 1,
    flexDirection: 'column',
    alignContent: 'flex-start',
  },
  screenContent: {
    flex: 1,
    width: windowWidth,
    height: windowHeight,
    flexDirection: 'column',
    alignItems: 'center',
  },
  inviteBox: {
    width: windowWidth,
    height: windowHeight * 0.15,
    flexDirection: 'column',
    alignItems: 'center',
    justifyContent: 'center',
  },
  inviteText: {
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.025,
    color: Themes.colors.darkBrown,
    alignItems: 'center',
    justifyContent: "space-around",
  },
  mail: {
    width: windowWidth,
    height: windowHeight,
    alignItems: 'center',

  },
  mailButtonRow: {
    width: windowWidth,
    height: windowHeight * 0.40,
    alignItems: 'center',
    flexDirection: 'row',
    justifyContent: 'space-around',
    paddingHorizontal: windowWidth * 0.10
  },
  mailButton: {
    width: windowWidth * 0.20,
    height: windowWidth * 0.20,
    alignItems: 'center',
    justifyContent: "center",
    backgroundColor: Themes.colors.blue,
    borderRadius: 99999,
  },
  mailButtonText: {
    color: Themes.colors.darkBrown,
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.020,
  },
  pigIcon: {
    width: windowWidth * 0.35,
    height: windowWidth * 0.35,
  },
  navBox: {
    width: windowWidth,
    height: windowHeight * 0.15,
    flexDirection: 'row',
    justifyContent: "center",
    alignItems: "center",
    padding: 50,
    paddingBottom: windowHeight * 0.12,
    paddingLeft: windowHeight * 0.161
  },
  top_container: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
    paddingBottom: windowHeight * 0.67
  },
  buttonText: {
    color: Themes.colors.darkBrown,
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.020,
  },
  titleText: {
    color: Themes.colors.darkBrown,
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.030,
  },
  backButton: {
    width: windowWidth * 0.30,
    height: windowHeight * 0.07,
    alignItems: 'center',
    justifyContent: "center",
    backgroundColor: Themes.colors.pink,
    borderRadius: 10,
    marginTop: 30
  },
  headerbar: {
    width: windowWidth,
    height: windowHeight * 0.025,
    flexDirection: 'row',
    alignItems: 'flex-start',
    justifyContent: 'space-between',
    backgroundColor: Themes.colors.background,
  },
  homeButtonImg: {
    width: windowHeight * 0.10 * 0.60,
    height: windowHeight * 0.10 * 0.60,
    justifyContent: 'center',
    alignItems: 'flex-start',
    marginHorizontal: 5
  },
  chatButtonImg: {
    width: windowHeight * 0.10 * 0.60,
    height: windowHeight * 0.10 * 0.60,
    justifyContent: 'center',
    alignItems: 'flex-end',
    marginHorizontal: 5
  },
  greetingBar: {
    width: windowWidth,
    height: windowHeight * 0.05,
    flexDirection: 'column',
    alignItems: 'center',
    justifyContent: "center",
  },
  greetingText: {
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.045,
    color: Themes.colors.darkBrown,
    alignItems: 'center',
    justifyContent: "space-around",

  }
})