import { Pressable, SafeAreaView, ImageBackground, StyleSheet, Text, View, Dimensions, Image, PixelRatio, FlatList } from "react-native";
import { Images, Themes } from "../../../assets/Themes";
import Constants from 'expo-constants';
import React, { useState } from 'react';
const windowWidth = Dimensions.get('window').width;
const windowHeight = Dimensions.get('window').height;


const Header = (props) => {
  return (
    <View>
      <View style={styles.headerbar}>
        <Pressable onPress={() => props.nav.navigate('Home', { username: props.username })}>
          <Image
            style={styles.homeButtonImg}
            source={Images.homeButton}
          />
        </Pressable>

      </View>
    </View>
  );
}

const Nav = (props) => {
  return (
    <View style={styles.navBox}>
      <View style={Themes.shadows}>
        <Pressable style={styles.backButton} onPress={() => props.nav.navigate('MainFriendScreen', { username: props.username })}>
          <Text style={styles.buttonText}>
            BACK TO FRIENDS
          </Text>
        </Pressable>
      </View>
    </View>
  );
}

export default function InviteRequestScreen({ navigation, route }) {

  return (
    <ImageBackground
      style={styles.container}
      source={Images.invScreen}>
      <View style={styles.top_container}>
        <Header nav={navigation} username={route.params.username} />

      </View>
      <Nav nav={navigation} username={route.params.username} />
    </ImageBackground>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: Themes.colors.background,
    paddingTop: Constants.statusBarHeight,
    alignItems: 'center',
    justifyContent: 'space-between',
  },
  top_container: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
    paddingBottom: windowHeight * 0.67
  },
  headerbar: {
    width: windowWidth,
    height: windowHeight * 0.025,
    flexDirection: 'row',
    alignItems: 'flex-start',
    justifyContent: 'space-between',
    backgroundColor: Themes.colors.background,
    paddingLeft: windowWidth * .012,
    paddingBottom: windowHeight * .068
  },
  crops_container: {
    height: windowHeight * 0.65,
    alignItems: "flex-end"
  },
  navBox: {
    width: windowWidth,
    height: windowHeight * 0.15,
    flexDirection: 'row',
    justifyContent: "center",
    alignItems: "center",
    padding: 50,
    paddingBottom: windowHeight * 0.129,
    paddingLeft: windowHeight * 0.161
  },
  backButton: {
    width: windowWidth * 0.30,
    height: windowHeight * 0.07,
    alignItems: 'center',
    justifyContent: "center",
    backgroundColor: Themes.colors.pink,
    borderRadius: 10,
    marginTop: 30
  },
  buttonText: {
    color: Themes.colors.darkBrown,
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.020,
  },
})
