import { Pressable, SafeAreaView, ImageBackground, StyleSheet, Text, View, Dimensions, Image, PixelRatio, FlatList } from "react-native";
import { Images, Themes } from "../../../assets/Themes";
import Constants from 'expo-constants';
import React, { useState } from 'react';
const windowWidth = Dimensions.get('window').width;
const windowHeight = Dimensions.get('window').height;


const Header = (props) => {
  return (
    <View>
      <View style={styles.headerbar}>
        <Pressable onPress={() => props.nav.navigate('Home', { username: props.username })}>
          <Image
            style={styles.homeButtonImg}
            source={Images.homeButton}
          />
        </Pressable>
      </View>
      <View style={styles.greetingBar}>
        <Text style={styles.greetingText}>
          Open Invite
        </Text>
      </View>
      <View style={styles.inviteBox}>
        <Text style={styles.inviteText}>
          Your friend wants you to
        </Text>
        <Text style={styles.inviteText}>
          visit them.
        </Text>
      </View>
    </View>
  );
}

const Nav = (props) => {
  return (
    <View style={styles.navBox}>
      <View style={Themes.shadows}>
        <Pressable style={styles.backButton} onPress={() => props.nav.navigate('MainFriendScreen', { username: props.username })}>
          <Text style={styles.buttonText}>
            BACK
          </Text>
        </Pressable>
      </View>
    </View>
  );
}

const accept = (nav, route) => {
  route.params.setMail(false);
  nav.navigate('FriendGarden', { username: route.params.username });
}

const reject = (nav, route) => {
  route.params.setMail(false);
  nav.navigate('MainFriendScreen', { username: route.params.username });
}

export default function MailInviteScreen({ navigation, route }) {

  return (
    <SafeAreaView style={styles.container}>
      <View style={styles.friendsScreen}>
        <Header nav={navigation} username={route.params.username} />
        <View style={styles.screenContent}>

          <ImageBackground
            style={styles.mail}
            source={Images.openMail}
            resizeMethod='resize'
            resizeMode='contain'>
            <Image
              style={[styles.pigIcon, {
                position: 'relative',
                top: "10%",
                right: "25%"
              }]}
              source={Images.pigFace} />
            <View
              style={[styles.mailButtonRow,
              {
                position: "relative",
                top: "5%"
              }]}
            >
              <View style={Themes.shadows}>
              <Pressable onPress={() => reject(navigation, route)}>
                <Image
                  style={styles.mailButton}
                  source={Images.noButton}
                />
              </Pressable>
              </View>
              
              <View style={Themes.shadows}>
              <Pressable onPress={() => accept(navigation, route)}>
                <Image
                  style={styles.mailButton}
                  source={Images.yesButton}
                />
              </Pressable>
              </View>
            </View>
          </ImageBackground>
        </View>
        <Nav nav={navigation} username={route.params.username} />
      </View>
    </SafeAreaView>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: Themes.colors.background,
    flex: 1,
    paddingTop: Constants.statusBarHeight,
    alignItems: 'center',
    justifyContent: 'center',
  },
  friendsScreen: {
    flex: 1,
    flexDirection: 'column',
    alignContent: 'flex-start',
  },
  screenContent: {
    flex: 1,
    width: windowWidth,
    height: windowHeight * 0.45,
    flexDirection: 'column',
    alignItems: 'center',
  },
  inviteBox: {
    width: windowWidth,
    height: windowHeight * 0.15,
    flexDirection: 'column',
    alignItems: 'center',
    justifyContent: 'center',
  },
  inviteText: {
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.025,
    color: Themes.colors.darkBrown,
    alignItems: 'center',
    justifyContent: "space-around",
  },
  mail: {
    width: windowWidth * 0.87,
    height: windowHeight * 0.60,
    alignItems: 'center',
  },
  mailButtonRow: {
    width: windowWidth,
    height: windowHeight * 0.40,
    alignItems: 'center',
    flexDirection: 'row',
    justifyContent: 'space-around',
    paddingHorizontal: windowWidth * 0.10
  },
  mailButton: {
    width: windowWidth * 0.20,
    height: windowWidth * 0.20,
    alignItems: 'center',
    justifyContent: "center",
    borderRadius: 99999,
  },
  mailButtonText: {
    color: Themes.colors.darkBrown,
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.020,
  },
  pigIcon: {
    width: windowWidth * 0.35,
    height: windowWidth * 0.35,
  },
  navBox: {
    width: windowWidth,
    height: windowHeight * 0.15,
    flexDirection: 'row',
    justifyContent: "center",
    alignItems: "center",
    padding: 50,
  },
  buttonText: {
    color: Themes.colors.darkBrown,
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.020,
  },
  backButton: {
    width: windowWidth * 0.30,
    height: windowHeight * 0.07,
    alignItems: 'center',
    justifyContent: "center",
    backgroundColor: Themes.colors.pink,
    borderRadius: 10,
    marginTop: 30
  },
  headerbar: {
    width: windowWidth,
    height: windowHeight * 0.025,
    flexDirection: 'row',
    alignItems: 'flex-start',
    backgroundColor: Themes.colors.background,
  },
  homeButtonImg: {
    width: windowHeight * 0.10 * 0.60,
    height: windowHeight * 0.10 * 0.60,
    justifyContent: 'center',
    alignItems: 'flex-start',
    marginHorizontal: 5
  },
  greetingBar: {
    width: windowWidth,
    height: windowHeight * 0.05,
    flexDirection: 'column',
    alignItems: 'center',
    justifyContent: "center",
  },
  greetingText: {
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.045,
    color: Themes.colors.darkBrown,
    alignItems: 'center',
    justifyContent: "space-around",

  }
})