import { Pressable, SafeAreaView, ImageBackground, StyleSheet, Text, View, Dimensions, Image, PixelRatio, FlatList } from "react-native";
import { Images, Themes } from "../../../assets/Themes";
import Constants from 'expo-constants';
import React, { useState } from 'react';
const windowWidth = Dimensions.get('window').width;
const windowHeight = Dimensions.get('window').height;

const Header = (props) => {
  return (
    <View>
      <View style={styles.headerbar}>
        <Pressable onPress={() => props.nav.navigate('Home', { username: props.username })}>
          <Image
            style={styles.homeButtonImg}
            source={Images.homeButton}
          />
        </Pressable>
      </View>
      <View style={styles.greetingBar}>
        <Text style={styles.greetingText}>
          {props.username}'s Friends
        </Text>
        <Text style={styles.subtext}>
          Tap to interact!
        </Text>
      </View>
    </View>
  );
}

const Nav = () => {
  return (
    <View style={styles.navBox}>
      <Text style={styles.subtext}>
        Expand your neighborhood by
      </Text>
      <Text style={styles.subtext}>
        making new friends!
      </Text>
      <View style={Themes.shadows}>
        <Pressable style={styles.inviteButton}>
          <Text style={styles.buttonText}>
            INVITE CONTACTS
          </Text>
        </Pressable>
      </View>
    </View>

  );
}

class MainFriendScreen extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      mail: this.props.route.params.mail
    }

    this.nav = this.props.navigation;
    this.params = this.props.route.params;
    this.setMail = this.setMail.bind(this);
  }

  setMail(bool) {
    this.setState({ mail: bool }, () => {
      this.params.setMail(bool);
    })
  }
  render() {
    return (
      <SafeAreaView style={styles.container}>
        <View style={styles.friendsScreen}>
          <Header nav={this.nav} username={this.params.username} />
          <View style={styles.screenContent}>
            <View style={styles.houseRow}>
              <Pressable onPress={() => { this.state.mail ? this.nav.navigate('MailScreen', { username: this.params.username, setMail: this.setMail }) : this.nav.navigate('PigStatus', { username: this.params.username }) }}>
                <Image
                  style={styles.houseImage}
                  source={this.state.mail ? Images.pigMail : Images.pigHouse}>
                </Image>
              </Pressable>
              <Pressable onPress={() => this.nav.navigate('BunnyStatus', { username: this.params.username })}>
                <Image style={styles.houseImage}
                  source={Images.rabbitHouse} />
              </Pressable>
            </View>
            <View style={[styles.houseRow, { paddingBottom: 60 }]}>
              <Pressable onPress={() => this.nav.navigate('MouseStatus', { username: this.params.username })}>
                <Image style={styles.houseImage}
                  source={Images.mouseHouse} />
              </Pressable>
            </View>
          </View>
          <Nav />
        </View>
      </SafeAreaView>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: Themes.colors.background,
    flex: 1,
    paddingTop: Constants.statusBarHeight,
    alignItems: 'center',
    justifyContent: 'center',
  },
  friendsScreen: {
    flex: 1,
    flexDirection: 'column',
    alignContent: 'flex-start',
  },
  screenContent: {
    width: windowWidth,
    height: windowHeight * 0.55,
    flexDirection: 'column',
    alignItems: 'center',
    padding: 30
  },
  houseRow: {
    width: windowWidth,
    height: windowHeight * 0.30,
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
    paddingHorizontal: 30

  },
  houseImage: {
    alignItems: 'center',
  },

  navBox: {
    width: windowWidth,
    height: windowHeight * 0.25,
    flexDirection: 'column',
    justifyContent: "center",
    alignItems: "center",
    padding: 50,
    marginTop: 20
  },
  buttonText: {
    color: Themes.colors.darkBrown,
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.020,
  },

  inviteButton: {
    width: windowWidth * 0.55,
    height: windowHeight * 0.07,
    alignItems: 'center',
    justifyContent: "center",
    backgroundColor: Themes.colors.greenButton,
    borderRadius: 10,
    marginTop: 10
  },


  headerbar: {
    width: windowWidth,
    height: windowHeight * 0.025,
    flexDirection: 'row',
    alignItems: 'flex-start',
    backgroundColor: Themes.colors.background,
  },
  homeButtonImg: {
    width: windowHeight * 0.10 * 0.60,
    height: windowHeight * 0.10 * 0.60,
    justifyContent: 'center',
    alignItems: 'flex-start',
    marginHorizontal: 5
  },
  greetingBar: {
    width: windowWidth,
    height: windowHeight * 0.10,
    flexDirection: 'column',
    alignItems: 'center',
    justifyContent: "center",
  },
  greetingText: {
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.045,
    color: Themes.colors.darkBrown,
    alignItems: 'center',
    justifyContent: "space-around",
    padding: 10
  },
  subtext: {
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.025,
    color: Themes.colors.darkBrown,
    alignItems: 'center',
    justifyContent: "space-around",
  }

})

export default MainFriendScreen;