import { Pressable, SafeAreaView, ImageBackground, StyleSheet, Text, View, Dimensions, Image, PixelRatio, FlatList } from "react-native";
import { Images, Themes } from "../../../assets/Themes";
import Constants from 'expo-constants';
import React, { useState } from 'react';
const windowWidth = Dimensions.get('window').width;
const windowHeight = Dimensions.get('window').height;

function InviteButton(props) {
  return (
    <View style={Themes.shadows}>
      <Pressable onPress={() => props.nav.navigate('InviteRequestScreen', { username: props.username })} style={styles.questionButton}>
        <Text style={styles.questionButtonText}>
          {props.text}
        </Text>
      </Pressable>
    </View>
  );
}

function VisitButton(props) {
  return (
    <View style={Themes.shadows}>
      <Pressable onPress={() => props.nav.navigate('VisitRequestScreen', { username: props.username })} style={styles.questionButton}>
        <Text style={styles.questionButtonText}>
          {props.text}
        </Text>
      </Pressable>
    </View>
  );
}



class StatusTemplate extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      emotion: this.props.emotion,
      image: this.props.image,
    };

    this.nav = this.props.nav;
  }








  render() {
    return (
      <SafeAreaView style={styles.container}>
        <View style={styles.friendsScreen}>

          <View>
            <View style={styles.headerbar}>
              <Pressable onPress={() => this.nav.navigate('Home', { username: this.props.username })}>
                <Image
                  style={styles.homeButtonImg}
                  source={Images.homeButton}
                />
              </Pressable>
            </View>
            <View style={styles.greetingBar}>
              <Text style={styles.greetingText}>
                Your Friend's Status
              </Text>
            </View>
            <View style={styles.inviteBox}>
              <Text style={styles.inviteText}>
                Your friend is feeling
              </Text>
              <Text style={styles.inviteText}>
                {this.state.emotion} today.
              </Text>
            </View>
          </View>


          <View style={styles.screenContent}>
            <View style={styles.iconStyle}>
              <Image
                source={this.state.image}
                resizeMode="cover" />
            </View>
            <InviteButton nav={this.nav} username={this.props.username} text={"INVITE THEM OVER"} />
            <VisitButton nav={this.nav} username={this.props.username} text={"ASK TO VISIT THEM"} />
          </View>

          <View style={styles.navBox}>
            <View style={Themes.shadows}>
              <Pressable style={styles.backButton} >
                <Text style={styles.buttonText}>
                  BACK
                </Text>
              </Pressable>
            </View>
          </View>


        </View>
      </SafeAreaView>
    );
  }

}

export default StatusTemplate;

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: Themes.colors.background,
    flex: 1,
    paddingTop: Constants.statusBarHeight,
    alignItems: 'center',
    justifyContent: 'center',
  },
  friendsScreen: {
    flex: 1,
    flexDirection: 'column',
    alignContent: 'flex-start',
  },
  screenContent: {
    flex: 1,
    width: windowWidth,
    height: windowHeight * 0.45,
    flexDirection: 'column',
    alignItems: 'center',
    padding: 10
  },
  inviteBox: {
    width: windowWidth,
    height: windowHeight * 0.15,
    flexDirection: 'column',
    alignItems: 'center',
    justifyContent: 'center',
  },
  inviteText: {
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.025,
    color: Themes.colors.darkBrown,
    alignItems: 'center',
    justifyContent: "space-around",
  },
  questionButton: {
    width: windowWidth * 0.80,
    height: windowHeight * 0.08,
    alignItems: 'center',
    justifyContent: "center",
    backgroundColor: Themes.colors.greenButton,
    borderRadius: 10,
    margin: 5
  },
  questionButtonText: {
    color: Themes.colors.darkBrown,
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.025,
  },
  iconStyle: {
    width: windowWidth * 0.60,
    height: windowHeight * 0.35,
    alignItems: 'center',
    justifyContent: 'center',
    marginBottom: 20
  },
  navBox: {
    width: windowWidth,
    height: windowHeight * 0.15,
    flexDirection: 'row',
    justifyContent: "center",
    alignItems: "center",
    padding: 50,
    paddingBottom: 20
  },
  buttonText: {
    color: Themes.colors.darkBrown,
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.022,
  },
  backButton: {
    width: windowWidth * 0.30,
    height: windowHeight * 0.07,
    alignItems: 'center',
    justifyContent: "center",
    backgroundColor: Themes.colors.pink,
    borderRadius: 10,
    marginTop: 30
  },
  headerbar: {
    width: windowWidth,
    height: windowHeight * 0.025,
    flexDirection: 'row',
    alignItems: 'flex-start',
    backgroundColor: Themes.colors.background,
  },
  homeButtonImg: {
    width: windowHeight * 0.10 * 0.60,
    height: windowHeight * 0.10 * 0.60,
    justifyContent: 'center',
    alignItems: 'flex-start',
    marginHorizontal: 5
  },
  greetingBar: {
    width: windowWidth,
    height: windowHeight * 0.06,
    flexDirection: 'column',
    alignItems: 'center',
    justifyContent: "center",
  },
  greetingText: {
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.037,
    color: Themes.colors.darkBrown,
    alignItems: 'center',
    justifyContent: "space-around",
    marginTop: 10
  }
})