import React from 'react';
import { Pressable, ScrollView, ImageBackground, StyleSheet, Text, View, Dimensions, Image, PixelRatio, FlatList } from "react-native";
import Constants from "expo-constants";
import { Images, Themes } from "../../../assets/Themes";


const windowWidth = Dimensions.get("window").width;
const windowHeight = Dimensions.get("window").height;
class PastData extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
        }
    }



    render() {
        console.log(this.props.surveys);
        const weekday = ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"];
        const faces = ["", <Image source={Images.depressedColor}></Image>, <Image source={Images.sadColor}></Image>, <Image source={Images.midColor}></Image>, <Image source={Images.goodColor}></Image>, <Image source={Images.greatColor}></Image>];
        let temp = [...this.props.surveys];
        return (
            temp.reverse().map((survey, index) => {
                console.log(survey.date)
                if (survey.completed) {
                    return (
                        <View style={Themes.shadows} key={"s" + index}>
                        <View style={styles.summary}>
                            <View style={{flexDirection: 'row', justifyContent: 'center'}}>
                            <Text style={styles.bold}> 
                                Summary From {weekday[survey.date.getDay()]}
                            </Text>
                            </View>

                            <View style={styles.grid}>
                            <View style={styles.data_row}>
                            <Text style={[styles.text_container, {alignItems: 'flex-start'}]}>
                                Mind:
                            </Text>
                            <Text style={[styles.result, {alignItems: 'flex-end'}]}> {faces[survey.mind]} </Text>
                            </View>

                            <View style={styles.data_row}>
                            <Text style={[styles.text_container, {alignItems: 'flex-start'}]}>
                                Body:
                            </Text>
                            <Text style={[styles.result, {alignItems: 'flex-end'}]}> {faces[survey.body]} </Text>
                            </View>

                            <View style={styles.data_row_list}>
                            <Text style={styles.text_container}> 
                                Feelings:
                            </Text>
                            <Text style={styles.result}> {survey.selectedEmotions.map((element, index) => {
                                if (index === survey.selectedEmotions.length - 1) {
                                    return <Text key={"e" + index}>{element} </Text>;
                                }
                                else {
                                    return <Text key={"e" + index}>{element}, </Text>;
                                }
                            })
                            } </Text>
                            </View>

                            <View style={styles.data_row_list}>
                            <Text style={styles.text_container}>
                                Physical feelings:
                            </Text>
                            <Text style={styles.result}> {survey.selectedAilments.map((element, index) => {
                                if (index === survey.selectedAilments.length - 1) {
                                    return <Text key={"a" + index} >{element}</Text>;
                                }
                                else {
                                    return <Text key={"a" + index}>{element},</Text>;
                                }
                            })
                            } </Text>
                            </View>

                            <View style={{margin: 5}}>
                                <Text style={[styles.text_container, {justifyContent: 'center'}]}>
                                    Discomfort:
                                </Text>
                                {survey.bodyDiscomfort ?
                                    <View style={styles.image_container}>
                                        <Image
                                            source={Images.bear_dot}
                                            style={styles.img}
                                        />
                                    </View>
                                    :
                                    <View style={styles.image_container}>
                                        <Image
                                            source={Images.bearBody}
                                            style={styles.img}
                                        />
                                    </View>}
                            </View>
                            </View>
                        </View>
                        </View>
                    );
                }
            })
        );
    }
}

export default PastData;

const styles = StyleSheet.create({
    container: {
        flex: 1,
        backgroundColor: Themes.colors.background,
        padding: windowWidth * 0.025,
    },
    summary: {
        margin: 20,
        flex: 1,
        flexDirection: 'column',
        textAlign: "center",
        color: Themes.colors.black,
        backgroundColor: Themes.colors.background,
        borderRadius: 10
    },
    grid: {
        paddingHorizontal: 20,
        flexDirection: 'column',
        justifyContent: "space-between",
    },
    data_row: {
        flexDirection: 'row',
        alignItems: 'center',
        margin: 5
    },
    data_row_list: {
        flexDirection: 'row',
        margin: 5
    },
    bold: {
        fontSize: PixelRatio.getFontScale() * windowHeight * 0.030,
        fontWeight: "bold",
        margin: 10,
        justifyContent: 'center',
        color: Themes.colors.darkBrown
    },
    text_container: {
        fontSize: PixelRatio.getFontScale() * windowHeight * 0.025,
        color: Themes.colors.black,
        fontWeight: "bold",
        padding: windowHeight * 0.0025,
    },
    result: {
        fontSize: PixelRatio.getFontScale() * windowHeight * 0.025,
        color: Themes.colors.darkBrown,
        fontWeight: "bold",
        padding: windowHeight * 0.0025,
        flex: 1, 
        flexWrap: 'wrap'
    },
    image_container: {
        alignItems: "center",
        justifyContent: "center",
        margin: 2
    },
    img: {
        width: windowHeight * 0.06,
        height: windowHeight * 0.10,
        justifyContent: 'center',
        alignItems: 'flex-end',
        paddingTop: windowHeight * 0.01,
        margin: 3
    },
});