import React, { useState } from "react";
import { Pressable, StyleSheet, Text, View, Dimensions, Image, PixelRatio } from "react-native";
import { Images, Themes } from "../../../assets/Themes";
import { Ionicons } from "@expo/vector-icons";
const windowWidth = Dimensions.get("window").width;
const windowHeight = Dimensions.get("window").height;

class HomeScreenTopBar extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      time: {}
    };

    this.timer = 0;
  }

  getTimeLeft() {
    let midnight = new Date();
    midnight.setHours(24, 0, 0, 0);
    midnight.setMinutes(0);
    midnight.setSeconds(0);
    midnight.setMilliseconds(0);
    let now = new Date();
    let diff = new Date(midnight.getTime() - now.getTime());
    let hours = diff.getHours();
    let minutes = diff.getMinutes();
    let seconds = diff.getSeconds();

    let obj = {
      hours: hours,
      mins: minutes,
      secs: seconds,
      total_secs: hours * 360 + minutes * 60 + seconds
    };
    return obj;
  }

  componentDidMount() {
    let timeLeft = this.getTimeLeft();
    this.setState({ time: timeLeft });
  }

  componentDidUpdate(prevProps) {
    if (prevProps.completed !== this.props.completed) {
      this.timer = setInterval(() => this.countDown(), 1000);
    }
  }

  componentWillUnmount() {
    clearInterval(this.timer);
  }

  countDown() {
    let seconds = this.state.seconds - 1;
    this.setState({
      time: this.getTimeLeft(),
    });

    if (seconds === 0) {
      this.props.setCompleted(false);
      this.props.setMind(0);
      this.props.setBody(0);
      this.props.setSelectedEmotions([]);
      this.props.setSelectedAilments([]);
      this.props.setBodyDiscomfort(false);
    }
  }

  render() {
    return (
      <View style={styles.navBox}>
        <View style={Themes.shadows}>
          <Pressable
            style={styles.chartButton}
            onPress={() => this.props.nav.navigate("GraphScreen", {
              mind: this.props.mind,
              body: this.props.body,
              selectedEmotions: this.props.selectedEmotions,
              selectedAilments: this.props.selectedAilments,
              bodyDiscomfort: this.props.bodyDiscomfort,
              completed: this.props.completed,
              username: this.props.username,
            })}>
            <Image source={Images.graph} />
          </Pressable>
        </View>
        <View style={Themes.shadows}>
          <Pressable
            style={styles.surveyButton}
            onPress={() => {
              if (this.props.completed) {
                this.props.nav.navigate("CompletionScreen", {
                  setCompleted: this.props.setCompleted,
                  username: this.props.username
                })
              }
              else {
                this.props.nav.navigate("Survey1", {
                  mind: this.props.mind,
                  setMind: this.props.setMind,
                  body: this.props.body,
                  setBody: this.props.setBody,
                  emotions: this.props.emotions,
                  setEmotions: this.props.setEmotions,
                  selectedEmotions: this.props.selectedEmotions,
                  setSelectedEmotions: this.props.setSelectedEmotions,
                  ailments: this.props.ailments,
                  setAilments: this.props.setAilments,
                  selectedAilments: this.props.selectedAilments,
                  setSelectedAilments: this.props.setSelectedAilments,
                  bodyDiscomfort: this.props.bodyDiscomfort,
                  setBodyDiscomfort: this.props.setBodyDiscomfort,
                  completed: this.props.completed,
                  setCompleted: this.props.setCompleted,
                  username: this.props.username
                });
              }
            }}
          >
            <Text style={styles.buttonText}>DAILY SURVEY</Text>
            {this.props.completed ? <Text>{this.state.time.hours}:{this.state.time.mins}:{this.state.time.secs.length === 1 ? "0" + this.state.time.secs : this.state.time.secs}</Text> : <Text style={styles.invisible} />}
          </Pressable>
        </View>
        <View style={Themes.shadows}>
          <Pressable
            style={styles.friendsButton}
            onPress={() => this.props.nav.navigate("MainFriendScreen", {
              username: this.props.username,
              mail: this.props.mail,
              setMail: this.props.setMail
            })}
          >
            <Ionicons name="ios-people" size={28} />
          </Pressable>
        </View>
      </View>
    );
  }
};

const styles = StyleSheet.create({
  navBox: {
    width: windowWidth,
    height: windowHeight * 0.2,
    flexDirection: "row",
    justifyContent: "center",
    alignItems: "flex-start",
    padding: 30,
  },
  chartButton: {
    width: windowWidth * 0.15,
    height: windowHeight * 0.07,
    alignItems: "center",
    justifyContent: "center",
    backgroundColor: Themes.colors.greenButton,
    borderRadius: 10,
    marginHorizontal: 10,
  },
  buttonText: {
    color: Themes.colors.black,
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.025,
  },
  friendsButton: {
    width: windowWidth * 0.15,
    height: windowHeight * 0.07,
    alignItems: "center",
    justifyContent: "center",
    backgroundColor: Themes.colors.greenButton,
    borderRadius: 10,
    marginHorizontal: 10,
  },
  surveyButton: {
    width: windowWidth * 0.5,
    height: windowHeight * 0.07,
    alignItems: "center",
    justifyContent: "center",
    backgroundColor: Themes.colors.greenButton,
    borderRadius: 10,
    marginHorizontal: 10,
  },
  invisible: {
    width: 0,
    height: 0
  }
});

export default HomeScreenTopBar;
