import * as React from 'react';
import { ScrollView, ImageBackground, Pressable, StyleSheet, Text, View, Dimensions, Image, PixelRatio } from 'react-native';
import Constants from "expo-constants";
import { Images, Themes } from '../../../assets/Themes';
const windowWidth = Dimensions.get('window').width;
const windowHeight = Dimensions.get('window').height;

const Header = (props) => {
  return (
    <View>
      <View style={styles.headerbar}>
        <Pressable onPress={() => props.nav.navigate('Home', { username: props.username })}>
          <Image
            style={styles.homeButtonImg}
            source={Images.homeButton}
          />
        </Pressable>
        <Image style={styles.coinImg} source={Images.coin} />
      </View>
      <View style={styles.greetingBar}>
        <Text style={styles.greetingText}>
          Hi {props.username}!
        </Text>
      </View>
    </View>
  );
}

export default function Inventory({ navigation, route }) {
  console.log(route);
  return (
    <View style={styles.container}>
      <Header nav={navigation} username={route.params.username} />
      <ScrollView>
        <View style={styles.box}>
          <Image style={styles.background} source={Images.inventory}>

          </Image>
        </View>
        <View style={{ width: windowWidth, height: windowHeight * 0.20 }}></View>
      </ScrollView>
    </View>
  )
}

const styles = StyleSheet.create({
  surveyScreen: {
    flex: 1,
    flexDirection: 'column',
    alignContent: 'flex-start',
  },
  container: {
    backgroundColor: Themes.colors.background,
    flex: 1,
    paddingTop: Constants.statusBarHeight,
    flexDirection: 'column'
  },
  box: {
    flexDirection: 'row',
    width: windowWidth * 0.95,
    alignContent: 'center',
    alignItems: 'center',
    justifyContent: 'center',
    margin: 10
  },
  background: {
    height: 1250,
    width: "100%",
  },
  headerbar: {
    width: windowWidth,
    height: windowHeight * 0.020,
    flexDirection: 'row',
    alignItems: 'flex-start',
    justifyContent: 'space-between',
    backgroundColor: Themes.colors.background
  },
  homeButtonImg: {
    width: windowHeight * 0.10 * 0.60,
    height: windowHeight * 0.10 * 0.60,
    justifyContent: 'center',
    alignItems: 'flex-start',
    marginHorizontal: 5
  },
  coinImg: {
    width: windowHeight * 0.10 * 0.60,
    height: windowHeight * 0.10 * 0.60,
    justifyContent: 'center',
    alignItems: 'flex-end',
    marginHorizontal: 10
  },
  greetingBar: {
    width: windowWidth,
    height: windowHeight * 0.10,
    flexDirection: 'row',
    alignItems: 'flex-start',
    justifyContent: "center",
  },
  greetingText: {
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.048,
    color: Themes.colors.darkBrown,
    alignItems: 'center',
    justifyContent: "space-around",
    paddingTop: 20
  }
})