import { Pressable, SafeAreaView, Platform, KeyboardAvoidingView, TextInput, StyleSheet, Text, View, Dimensions, Image, PixelRatio, Alert } from "react-native";
import { Images, Themes } from "../../../assets/Themes";
import Constants from 'expo-constants';
import React, { useState } from 'react';
const windowWidth = Dimensions.get('window').width;
const windowHeight = Dimensions.get('window').height;

export default function SignUp({ navigation }) {
  const [email, setEmail] = useState("");
  const [name, setName] = useState("");
  const [password, setPassword] = useState("");

  const submit = () => {
    if (name == '' || password == '') {
      Alert.alert(
        "ERROR",
        "You must submit a valid Username and Password!",
        [
          {
            text: "Back",
            style: "cancel",
          },
        ]
      );
    }
    else {
      navigation.navigate("Home", {
        username: name
      })
    }
  }
  return (
    <View style={styles.container}>
      <View style={styles.surveyScreen}>
        <View style={styles.header}>
          <View style={styles.welcomeBox}>
            <Image style={styles.logo}
              source={Images.lucidly} />
          </View>
        </View>
        <View style={styles.surveyContent}>
          <Text style={styles.field}>
            Username
          </Text>
          <View style={Themes.shadows}>
            <KeyboardAvoidingView behavior={Platform.OS === 'ios' ? 'padding' : 'height'}>

              <View style={styles.textinputrow}>
                <SafeAreaView style={styles.emotionBox}>
                  <TextInput
                    style={styles.textInput}
                    onChangeText={(newText) => setName(newText)}
                    placeholder={"                        "}
                    defaultValue={name}
                  />
                </SafeAreaView>
              </View>
            </KeyboardAvoidingView>
          </View>

          <Text style={styles.field}>
            Password
          </Text>
          <View style={Themes.shadows}>
            <KeyboardAvoidingView behavior={Platform.OS === 'ios' ? 'padding' : 'height'}>
              <View style={styles.textinputrow}>
                <SafeAreaView style={styles.emotionBox}>
                  <TextInput
                    style={styles.textInput}
                    onChangeText={(newText) => setPassword(newText)}
                    placeholder={"Lucidly123!"}
                    defaultValue={password}
                    secureTextEntry={true}
                  />
                </SafeAreaView>
              </View>
            </KeyboardAvoidingView>
          </View>
          <View style={styles.nav}>
            <View style={Themes.shadows}>
              <Pressable style={styles.createAccount} onPress={() => submit()}>
                <Text style={styles.createAccountText}>
                  Create Account
                </Text>
              </Pressable>
            </View>
          </View>
        </View>

      </View>
    </View>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: Themes.colors.background,
    paddingTop: Constants.statusBarHeight,
    alignItems: 'center',
    justifyContent: 'center',
  },
  surveyScreen: {
    flex: 1,
    flexDirection: 'column',
    alignContent: 'flex-start',
  },
  header: {
    width: windowWidth,
    height: windowHeight * 0.20,
    flexDirection: 'column',
    alignItems: 'center',
    padding: 10,
    flex: 1
  },
  logo: {
    alignItems: 'center',
    justifyContent: 'center',
    margin: 10,
    width: windowWidth * 0.60,
    resizeMode: 'contain'
  },
  welcomeBox: {
    margin: 5,
    flexDirection: 'row',
  },
  field: {
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.025,
    color: Themes.colors.darkBrown
  },
  surveyContent: {
    flex: 2,
    width: windowWidth,
    height: windowHeight * 0.60,
    flexDirection: 'column',
    alignItems: 'center',
  },
  textInput: {
    margin: 10,
    textAlign: 'center',
    justifyContent: 'center',
    backgroundColor: Themes.colors.white,
    borderRadius: 10,
    color: Themes.colors.black,
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.020,
  },
  textinputrow: {
    flexDirection: 'row',
    alignContent: 'center',
    marginBottom: 10,
  },
  title: {
    fontSize: 30,
    color: Themes.colors.black,
  },
  emotionBox: {
    width: windowWidth * 0.65,
    height: windowHeight * 0.05,
    flexDirection: 'row',
    margin: 10,
    alignItems: 'center',
    justifyContent: 'center',
    backgroundColor: Themes.colors.white,
    borderRadius: 10,
  },
  createAccount: {
    width: windowWidth * 0.65,
    height: windowHeight * 0.05,
    flexDirection: 'row',
    margin: 10,
    alignItems: 'center',
    justifyContent: 'center',
    backgroundColor: Themes.colors.greenButton,
    borderRadius: 10,
  },
  nav: {
    width: windowWidth,
    height: windowHeight * 0.20,
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    alignContent: 'center',
    marginVertical: 5

  },
  createAccountText: {
    color: Themes.colors.black,
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.020,
    alignItems: 'center',
    justifyContent: 'center',
  }
})