import {
  Pressable,
  ImageBackground,
  StyleSheet,
  Text,
  View,
  Dimensions,
  PixelRatio,
} from "react-native";
import { Images, Themes } from "../../../assets/Themes";
import Constants from "expo-constants";
import React, { useState } from "react";
const windowWidth = Dimensions.get("window").width;
const windowHeight = Dimensions.get("window").height;
import SurveyHeader from "./SurveyHeader";
import Survey3Nav from "./Survey3Nav";

class Survey3 extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      point1: this.props.route.params.bodyDiscomfort
    };
    this.nav = this.props.navigation;
    this.params = this.props.route.params;
  }

  togglePoint1 = () => {
    this.setState({ point1: !this.state.point1 }, () => {
      this.params.setBodyDiscomfort(this.state.point1);
    })
  }

  ClickBear = () => {
    return (
      <View style={styles.questionBox}>
        <Text style={styles.questionText}>Click the bear on the screen</Text>
        <Text style={styles.questionText}>where you feel discomfort.</Text>
      </View>
    );
  };

  render() {
    return (
      <View style={styles.container}>
        <View style={styles.surveyScreen}>
          <SurveyHeader nav={this.nav} username={this.params.username} />
          <View style={styles.surveyContent}>
            <this.ClickBear />
            <View style={styles.bearBox}>
              <ImageBackground
                style={styles.bearBackground}
                resizeMethod="resize"
                resizeMode="contain"
                source={Images.bearBody}
              >
                <Pressable
                  style={[
                    styles.dot,
                    {
                      backgroundColor: this.state.point1
                        ? Themes.colors.blue
                        : Themes.colors.bearBrown,
                    },
                  ]}
                  onPress={() => this.togglePoint1(1)}
                />
              </ImageBackground>
            </View>
          </View>
          <Survey3Nav
            nav={this.nav}
            mind={this.params.mind}
            setMind={this.params.setMind}
            body={this.params.body}
            setBody={this.params.setBody}
            emotions={this.params.emotions}
            setEmotions={this.params.setEmotions}
            ailments={this.params.ailments}
            setAilments={this.params.setAilments}
            selectedEmotions={this.params.selectedEmotions}
            setSelectedEmotions={this.params.setSelectedEmotions}
            selectedAilments={this.params.selectedAilments}
            setSelectedAilments={this.params.setSelectedAilments}
            bodyDiscomfort={this.state.point1}
            setBodyDiscomfort={this.params.setBodyDiscomfort}
            completed={this.params.completed}
            setCompleted={this.params.setCompleted}
            username={this.params.username}
          />
        </View>
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: Themes.colors.background,
    flex: 1,
    paddingTop: Constants.statusBarHeight,
    alignItems: "center",
    justifyContent: "center",
  },
  surveyScreen: {
    flex: 1,
    flexDirection: "column",
    alignContent: "flex-start",
  },
  surveyContent: {
    width: windowWidth,
    height: windowHeight * 0.6,
    flexDirection: "column",
    alignItems: "center",
  },
  questionBox: {
    width: windowWidth,
    height: windowHeight * 0.1,
    flexDirection: "column",
    alignItems: "center",
  },
  questionText: {
    color: Themes.colors.subtext,
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.024,
    alignContent: "center",
    justifyContent: "center",
  },
  bearBox: {
    width: windowWidth,
    height: windowHeight * 0.55,
    flexDirection: "column",
    alignItems: "center",
    justifyContent: "flex-start",
  },
  bearBackground: {
    width: windowWidth,
    height: "100%",
    justifyContent: "flex-start",
    alignItems: "center",
  },
  dot: {
    width: windowWidth * 0.25,
    height: windowWidth * 0.25,
    borderRadius: 99999,
    borderColor: "black",
    margin: 200,
  },
});

export default Survey3;
