import { Pressable, SafeAreaView, Platform, KeyboardAvoidingView, TextInput, StyleSheet, Text, View, Dimensions, Image, PixelRatio, FlatList } from "react-native";
import { Images, Themes } from "../../../assets/Themes";
import Constants from "expo-constants";
import React, { useState } from "react";
import SurveyHeader from "./SurveyHeader";
import Survey4Nav from "./Survey4Nav";
const windowWidth = Dimensions.get("window").width;
const windowHeight = Dimensions.get("window").height;
import EmotionList from "./EmotionList";

class Survey4 extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      ailments: this.props.route.params.ailments,
      text: "",
      selectedAilments: this.props.route.params.selectedAilments
    };

    this.selectAilments = this.selectAilments.bind(this);
    this.deselectAilments = this.deselectAilments.bind(this);

    this.nav = this.props.navigation;
    this.params = this.props.route.params;
  }

  setAilments(newAilments) {
    this.setState({ ailments: newAilments }, () => {
      this.params.setAilments(newAilments);
    });
  }

  setText(newText) {
    this.setState({ text: newText });
  }

  addAilment = () => {
    let newAilments = [...this.state.ailments];
    newAilments.push(this.state.text);
    this.setAilments(newAilments);
    this.setText("");
  };

  selectAilments(ailment) {
    let newSelectedAilments = [...this.state.selectedAilments];
    newSelectedAilments.push(ailment);
    this.setState({ selectAilments: newSelectedAilments },
      () => {
        this.params.setSelectedAilments(newSelectedAilments);
      });
  }

  deselectAilments(ailment) {
    let newSelectedAilments = [...this.state.selectedAilments];
    newSelectedAilments = newSelectedAilments.filter((value) => {
      return value !== ailment;
    })
    this.setState({ selectAilments: newSelectedAilments },
      () => {
        this.params.setSelectedAilments(newSelectedAilments);
      });
  }

  renderList = ({ item }) => {
    return (
      <EmotionList
        text={item}
        selected={this.state.selectedAilments}
        select={this.selectAilments}
        deselect={this.deselectAilments}
      />
    );
  };

  render() {
    return (
      <View style={styles.container}>
        <SurveyHeader nav={this.nav} username={this.params.username} />
        <View style={styles.surveyScreen}>
          <View style={styles.surveyContent}>
            <Text style={styles.questionText}>What are you feeling</Text>
            <Text style={styles.questionText}>physically today?</Text>
            <Text style={styles.questionText}></Text>
            <SafeAreaView styles={styles.flatList}>
              <FlatList
                data={this.state.ailments}
                renderItem={this.renderList}
                keyExtractor={(item, index) => item + index}
                ListFooterComponent={
                  <View>
                    <View style={Themes.shadows}>
                      <KeyboardAvoidingView
                        behavior={Platform.OS === "ios" ? "padding" : "height"}
                      >
                        <View style={styles.textinputrow}>
                          <TextInput
                            style={styles.textInput}
                            placeholder="Add Feeling"
                            onChangeText={(newText) => this.setText(newText)}
                            defaultValue={this.state.text}
                          />
                        </View>
                      </KeyboardAvoidingView>
                    </View>
                    <View
                      style={{ flexDirection: "row", justifyContent: "center" }}
                    >
                      <Pressable style={styles.button} onPress={this.addAilment}>
                        <Image
                          style={styles.buttonImage}
                          source={Images.addButton}
                        />
                      </Pressable>
                    </View>
                  </View>
                }
              />
            </SafeAreaView>
          </View>
        </View>
        <Survey4Nav
          nav={this.nav}
          mind={this.params.mind}
          setMind={this.params.setMind}
          body={this.params.body}
          setBody={this.params.setBody}
          emotions={this.params.emotions}
          setEmotions={this.params.setEmotions}
          ailments={this.params.ailments}
          setAilments={this.params.setAilments}
          selectedEmotions={this.params.selectedEmotions}
          setSelectedEmotions={this.params.setSelectedEmotions}
          selectedAilments={this.state.selectedAilments}
          setSelectedAilments={this.params.setSelectedAilments}
          bodyDiscomfort={this.params.bodyDiscomfort}
          setBodyDiscomfort={this.params.setBodyDiscomfort}
          completed={this.params.completed}
          setCompleted={this.params.setCompleted}
          username={this.params.username}
        />
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: Themes.colors.background,
    flex: 1,
    paddingTop: Constants.statusBarHeight,
    alignItems: "center",
    justifyContent: "center",
  },
  surveyScreen: {
    flex: 1,
    flexDirection: "column",
    alignContent: "flex-start",
  },
  surveyContent: {
    width: windowWidth,
    height: windowHeight * 0.6,
    flexDirection: "column",
    alignItems: "center",
  },
  questionBox: {
    width: windowWidth,
    height: windowHeight * 0.1,
    flexDirection: "column",
    alignItems: "center",
  },
  questionText: {
    color: Themes.colors.subtext,
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.024,
    alignContent: "center",
    justifyContent: "center",
  },
  flatList: {
    margin: 10,
    flexDirection: "column",
  },
  textInput: {
    width: windowWidth * 0.65,
    height: windowHeight * 0.05,
    flexDirection: "row",
    margin: 10,
    alignItems: "center",
    justifyContent: "center",
    backgroundColor: Themes.colors.white,
    borderRadius: 10,
    paddingHorizontal: 75,
    color: Themes.colors.black,
    fontSize: PixelRatio.getFontScale() * windowHeight * 0.024,
  },
  textinputrow: {
    flexDirection: "row",
    alignContent: "center",
    marginBottom: 10,
  },
  title: {
    fontSize: 30,
    color: Themes.colors.black,
  },
  button: {
    width: windowWidth * 0.16,
    height: windowWidth * 0.16,
    flexDirection: "row",
    alignItems: "center",
    justifyContent: "center",
    borderRadius: 99999,
    margin: 5,
  },
  buttonImage: {
    width: windowWidth * 0.1,
    height: windowWidth * 0.1,
    alignItems: "center",
    justifyContent: "center",
    borderRadius: 99999,
  },
  emotionBox: {
    width: windowWidth * 0.65,
    height: windowHeight * 0.05,
    flexDirection: "row",
    margin: 10,
    alignItems: "center",
    justifyContent: "center",
    backgroundColor: Themes.colors.white,
    borderRadius: 10,
  },
});

export default Survey4;
